@@ -1,73 +1,42 @@
 package App::dategrep::Iterator::File;
 use strict;
 use warnings;
-use Fcntl ":seek";
+use parent 'App::dategrep::Iterator';
+use Fcntl ':seek';
 use File::stat;
-use Moo;
-use FileHandle;
-extends 'App::dategrep::Iterator';
 
-has filename => ( is => 'ro', required => 1 );
-has blocksize => ( is => 'lazy' );
-
-sub can_seek { 1 }
-
-sub _build_blocksize {
-    my $self = shift;
-    return stat( $self->fh )->blksize || 8192;
-}
-
-sub _build_fh {
-    my $self     = shift;
-    my $filename = $self->filename;
-    open( my $fh, '<', $filename ) or die "Can't open $filename: $!\n";
-    return $fh;
-}
-
-sub seek {
+sub skip_to_start {
     my $self = shift;
 
-    my $min = $self->search( $self->start );
+    my $min = $self->_search( $self->{start} );
 
     if ( not defined $min ) {
-        $self->eof(1);
+        $self->{eof} = 1;
         return;
     }
 
-    my $line = $self->fh->getline;
+    my $line = $self->{fh}->getline;
     my ( $date, $error ) = $self->to_epoch($line);
 
-    if ( $date >= $self->end ) {
-        $self->eof(1);
+    if ( $date >= $self->{end} ) {
+        $self->{eof} = 1;
         return;
     }
 
-    $self->next_line($line);
-    $self->next_date($date);
+    $self->{next_line} = $line;
+    $self->{next_date} = $date;
     return;
 }
 
-sub byte_offsets {
-    my $self     = shift;
-    my $tell_beg = $self->search( $self->start );
-
-    if ( defined $tell_beg ) {
-        my $tell_end = $self->search( $self->end, $tell_beg );
-        return $tell_beg, $tell_end;
-    }
-
-    # return for empty file
-    return 0, -1;
-}
-
-sub search {
+sub _search {
     my $self = shift;
     my ( $key, $min_byte ) = @_;
-    my $fh = $self->fh;
+    my $fh = $self->{fh};
 
-    my $size      = stat($fh)->size;
-    my $blksize   = $self->blocksize;
-    my $multiline = $self->multiline;
+    my $size            = stat($fh)->size;
+    my $blksize         = stat($fh)->blksize || 8192;
+    my $multiline       = $self->{multiline};
+    my $skip_unparsable = $self->{skip_unparsable};
 
     # find the right block
     my ( $min, $max, $mid ) = ( 0, int( $size / $blksize ) );
@@ -81,14 +50,14 @@ sub search {
         $fh->seek( $mid * $blksize, SEEK_SET ) or return;
         $fh->getline if $mid;    # probably a partial line
       LINE: while (1) {
-            my $line = $fh->getline();
+            my $line = $fh->getline;
             if ( !$line ) {
                 ## This can happen if line size is way bigger than blocksize
                 last BLOCK;
             }
             my ($epoch) = $self->to_epoch($line);
             if ( !$epoch ) {
-                next LINE if $multiline || $self->skip_unparsable;
+                next LINE if $multiline || $skip_unparsable;
                 die "No date found in line $line";
             }
 
@@ -109,7 +78,7 @@ sub search {
         defined( my $line = $fh->getline ) or last;
         my ($epoch) = $self->to_epoch($line);
         if ( !$epoch ) {
-            next if $multiline || $self->skip_unparsable;
+            next if $multiline || $skip_unparsable;
             die "No date found in line $line";
         }
         if ( $epoch >= $key ) {
